@@ -40,6 +40,8 @@ from jsw_nx.packages.parse_cookie import parse_cookie
 from jsw_nx.packages.qs import qs
 from jsw_nx.packages.tmpl import tmpl
 from jsw_nx.packages.deep_each import deep_each
+from jsw_nx.packages.get_domain import get_domain
+from jsw_nx.packages.html2text import html2text
 from jsw_nx.packages.is_process_alive import is_process_alive
 from jsw_nx.packages.md5 import md5
 from jsw_nx.packages.replace_dict_all import replace_dict_all
@@ -54,5 +56,6 @@ from jsw_nx.classes.date import Date
 from jsw_nx.classes.fileutils import FileUtils as fileutils
 from jsw_nx.classes.tar import Tar as tar
 from jsw_nx.classes.json import JSON
+from jsw_nx.classes.pm2_manager import Pm2Manager
 from jsw_nx.classes.yaml import Yaml
 from jsw_nx.classes.ymd import Ymd
